:mod:`xoutil.proxy` - An objects proxy implementation
=====================================================

.. automodule:: xoutil.proxy
   :members: proxify, UNPROXIFING_CONTEXT

.. autoclass:: unboxed
   :members: __lshift__
